\name{plkhci}
\alias{plkhci}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Profile-likelihood based confidence intervals }
\description{
  Function to find \code{prob}*100\% likelihood ratio confidence intervals using
  profile-likelihood. Numerical solutions are obtained via a  
  modified  Newton-Raphson algorithm. The method is described in
  Venzon and Moolgavkar, Journal of the Royal Statistical Society,
  Series C vol 37, no.1, 1988, pp. 87-94. 
}
\usage{
plkhci(x, nlogf, label, prob=0.95, eps=.001, nmax=10, nfcn=0)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{ a list with components 'label' (of mode character, giving the
    names of each parameter), 'est'
    (vector containing the ML estimate), 'low' (vector with
    lower bounds), and 'upp' (vector with upper bounds) }
  \item{nlogf}{ the negative log of the density function (not necessarily
    normalized) for which samples are to be obtained }
  \item{label}{ parameter for which confidence bounds are computed }
  \item{prob}{ probability associated with the confidence interval }
  \item{eps}{ a numerical value. Convergence results when all
    (logit-transformed) derivatives are smaller \code{eps} }  
  \item{nmax}{ maximum number of Newton-Raphson iterations in each direction }
  \item{nfcn}{ number of function calls }
}
\value{
  Vector of length 2 giving the lower and upper p\% confidence bounds 
}
\author{ E. Georg Luebeck (FHCRC) }
\note{ Only a single parameter label can be passed to plkhci.}

%  ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{ \code{\link{logit.hessian}}, \code{\link{Plkhci}} }

\examples{
#Define the negative log-likelihood function
nloglhood=function(p) 
  return( -(log(choose(100,10))+10*log(p)+90*log(1-p)) )
#Minimize the negative log-likelihood
binom.fit=optim(0.5,nloglhood,lower=0.0001,upper=0.9999,
                  hessian=TRUE)
phat=binom.fit$par #The MLE

#Set up list for input into plkhci function
control.list=list(label="p",est=phat,low=0,upp=1)
#Calculate approximate 95% likelihood ratio CI
plkhci(control.list,nloglhood,"p")
}
\keyword{ distribution }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line




