\name{Plkhci}
\alias{Plkhci}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Modified version of plkhci
}
\description{
Modified version of plkhci that permits optional arguments (e.g., data)
to be passed to the negative log-likelihood function.
}
\usage{
Plkhci(x, nlogf, label, prob = 0.95, eps = 0.001, nmax = 10, nfcn = 0, ...)
}
\arguments{
  \item{x}{ a list with components 'label' (of mode character, giving the
    names of each parameter), 'est'
    (vector containing the ML estimate), 'low' (vector with
    lower bounds), and 'upp' (vector with upper bounds) }
  \item{nlogf}{ the negative log of the density function (not necessarily
    normalized) for which samples are to be obtained }
  \item{label}{ parameter for which confidence bounds are computed }
  \item{prob}{ probability associated with the confidence interval }
  \item{eps}{ a numerical value. Convergence results when all
    (logit-transformed) derivatives are smaller \code{eps} }  
  \item{nmax}{ maximum number of Newton-Raphson iterations in each direction }
  \item{nfcn}{ number of function calls }
  \item{...}{ any additional arguments to be passed to nlogf }
}
\value{
  Vector of length 2 giving the lower and upper p\% confidence bounds 
}
\seealso{ \code{\link{plkhci}} }
\examples{
#Define the negative log-likelihood function
nloglhood=function(p,y,m) 
  return( -(log(choose(m,y))+y*log(p)+(m-y)*log(1-p)) )

m=100; y=10
#Find the MLE
phat=optim(0.5,nloglhood,lower=0.0001,upper=0.9999,y=y,m=100)$par 

control.list=list(label="p",est=phat,low=0,upp=1)
#Calculate approximate 95% likelihood ratio CI
Plkhci(control.list,nlogf=nloglhood,"p",y=10,m=100)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
